#! /usr/bin/env python
import os
import traceback
import sys

sys.path.append(os.path.abspath(os.path.dirname(__file__) + '/../'))
from core import scrib

# Identify yourself and send default settings
scrib = scrib.scrib('cli', {
	'chatrate': 1.0,
	'maxwords': 30
})
settings = scrib.setcfg()

class ScribCLI:
	"""
	Module to interface console input and output with the Scrib learn
	and reply modules. Allows offline chat with Scrib.
	"""

	def __init__(self, scrib):
		self.start()

	def start(self):
		scrib.barf('ACT', "Scrib offline chat!")
		scrib.barf('ACT', "Type !quit to leave")
		scrib.barf('ACT', "Enter your name?\033[0m")
		name = raw_input("> ")
		scrib.barf('MSG', "Hello %s." % name)
		while 1:
			try:
				body = raw_input("> ")
			except (KeyboardInterrupt, EOFError):
				scrib.shutdown()
				return

			# Pass message to scrib
			scrib.reply(body)

	def output(self, message, args):
		"""
		Output a line of text.
		"""
		scrib.barf('MSG', message + "\033[0m")

if __name__ == "__main__":
	try:
		ScribCLI(scrib)
	# Supresses errors that ^c causes
	except SystemExit:
		pass
	# Cleanly exit scrib if ^c detected
	except KeyboardInterrupt:
		scrib.shutdown()
	# Barf if crash.
	except:
		scrib.barf('ERR', traceback.format_exc())
		scrib.shutdown()

	sys.exit()
